@@ -1,3 +1,3 @@
-__all__ = ["base_graph", "base_transform", "bond", "extrastats", "generator", "envir",
+__all__ = ["base_transform", "bond", "extrastats", "envir",
            "atom", "bond", "descriptors", "state", "base_graph_geo", "batch_feature"
            ]
