@@ -59,6 +59,8 @@ class _BaseStructureGraphGEO(BaseFeature):
         if collect is False:
             self.get_collect_data = lambda x: x
 
+        assert return_type in ["tensor", "np", "numpy", "array", "ndarray"]
+
         if collect is True:
             warnings.warn("The collect=True just used for temporary show!", UserWarning)
         if return_type != "tensor":
@@ -118,8 +120,10 @@ class _BaseStructureGraphGEO(BaseFeature):
 
             ret, self.support_ = zip(*rets)
 
-        if self.add_label:
+        if self.add_label and self.return_type == "tensor":
             [i.update({"label": torch.tensor([n, n])}) for n, i in enumerate(ret)]  # double for after.
+        else:
+            [i.update({"label": np.array([n, n])}) for n, i in enumerate(ret)]  # double for after.
         return ret
 
     def get_collect_data(self, graphs: List[Dict]):
@@ -175,7 +179,7 @@ class _BaseStructureGraphGEO(BaseFeature):
                            "to definition or specific names list.")
         elif len(set(file_names)) == len(structures):
             return file_names
-        elif len(set(file_names)) == "rank_number":
+        elif file_names == "rank_number":
             return ["raw_data_{}".format(i) for i in range(len(structures))]
         else:
             return names
@@ -294,12 +298,12 @@ class BaseStructureGraphGEO(_BaseStructureGraphGEO):
 
         Args:
             atom_converter: (BinaryMap) atom features converter. See Also:
-                :class:`featurebox.featurizers.atom.mapper.AtomTableMap` , :class:`featurebox.featurizers.atom.mapper.AtomJsonMap` ,
-                :class:`featurebox.featurizers.atom.mapper.AtomPymatgenPropMap`, :class:`featurebox.featurizers.atom.mapper.AtomTableMap`
+                :class:`featurebox.test_featurizers.atom.mapper.AtomTableMap` , :class:`featurebox.test_featurizers.atom.mapper.AtomJsonMap` ,
+                :class:`featurebox.test_featurizers.atom.mapper.AtomPymatgenPropMap`, :class:`featurebox.test_featurizers.atom.mapper.AtomTableMap`
             state_converter: (Converter) state features converter. See Also:
-                :class:`featurebox.featurizers.state.state_mapper.StructurePymatgenPropMap`
-                :mod:`featurebox.featurizers.state.statistics`
-                :mod:`featurebox.featurizers.state.union`
+                :class:`featurebox.test_featurizers.state.state_mapper.StructurePymatgenPropMap`
+                :mod:`featurebox.test_featurizers.state.statistics`
+                :mod:`featurebox.test_featurizers.state.union`
             **kwargs:
         """
         super().__init__(**kwargs)
@@ -343,7 +347,7 @@ class BaseStructureGraphGEO(_BaseStructureGraphGEO):
             else:
                 y = np.array(y, dtype=np.float32).ravel()[np.newaxis, :]
         else:
-            y = np.nan
+            y = np.array(np.nan)
 
         return {'y': y}
 
@@ -413,16 +417,16 @@ class StructureGraphGEO(BaseStructureGraphGEO):
                 "EconNN", "CrystalNN", "MinimumDistanceNNAll", "find_points_in_spheres","UserVoronoiNN"]
             atom_converter: (BinaryMap) atom features converter.
                 See Also:
-                :class:`featurebox.featurizers.atom.mapper.AtomTableMap` , :class:`featurebox.featurizers.atom.mapper.AtomJsonMap` ,
-                :class:`featurebox.featurizers.atom.mapper.AtomPymatgenPropMap`, :class:`featurebox.featurizers.atom.mapper.AtomTableMap`
+                :class:`featurebox.test_featurizers.atom.mapper.AtomTableMap` , :class:`featurebox.test_featurizers.atom.mapper.AtomJsonMap` ,
+                :class:`featurebox.test_featurizers.atom.mapper.AtomPymatgenPropMap`, :class:`featurebox.test_featurizers.atom.mapper.AtomTableMap`
             bond_converter: (Converter)
                 bond features converter, default=None.
             state_converter: (Converter)
                 state features converter.
                 See Also:
-                :class:`featurebox.featurizers.state.state_mapper.StructurePymatgenPropMap`
-                :mod:`featurebox.featurizers.state.statistics`
-                :mod:`featurebox.featurizers.state.union`
+                :class:`featurebox.test_featurizers.state.state_mapper.StructurePymatgenPropMap`
+                :mod:`featurebox.test_featurizers.state.statistics`
+                :mod:`featurebox.test_featurizers.state.union`
             bond_generator: (GEONNGet, str)
                 bond features converter.
             cutoff: (float)
@@ -458,6 +462,14 @@ class StructureGraphGEO(BaseStructureGraphGEO):
 
         center_indices, edge_index, edge_attr, edge_weight, center_prop = self.bond_generator.convert(structure)
 
+        # remove dup
+
+        index = edge_index[0] < edge_index[1]
+
+        edge_index = edge_index[:, index]
+        edge_weight = edge_weight[index]
+        edge_attr = edge_attr[index]
+
         if edge_weight.ndim == 2:
             if edge_weight.shape[1] == 3:
                 edge_weight = np.sum(edge_weight ** 2, axis=1) ** 0.5
